@@ -21,7 +21,7 @@ Usage::
     list_harvest_jobs_paginator: ListHarvestJobsPaginator = client.get_paginator("list_harvest_jobs")
     list_origin_endpoints_paginator: ListOriginEndpointsPaginator = client.get_paginator("list_origin_endpoints")
 """
-from mypy_boto3_mediapackage.client import MediaPackageClient as Client, MediaPackageClient
+from mypy_boto3_mediapackage.client import MediaPackageClient, MediaPackageClient as Client
 from mypy_boto3_mediapackage.paginator import (
     ListChannelsPaginator,
     ListHarvestJobsPaginator,
