@@ -17,7 +17,7 @@ Usage::
     list_origin_endpoints_paginator: ListOriginEndpointsPaginator = client.get_paginator("list_origin_endpoints")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_mediapackage.type_defs import (
     ListChannelsResponseTypeDef,
@@ -32,20 +32,20 @@ __all__ = ("ListChannelsPaginator", "ListHarvestJobsPaginator", "ListOriginEndpo
 
 class ListChannelsPaginator(Boto3Paginator):
     """
-    [Paginator.ListChannels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.2/reference/services/mediapackage.html#MediaPackage.Paginator.ListChannels)
+    [Paginator.ListChannels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.7/reference/services/mediapackage.html#MediaPackage.Paginator.ListChannels)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListChannelsResponseTypeDef, None, None]:
+    ) -> Iterator[ListChannelsResponseTypeDef]:
         """
-        [ListChannels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.2/reference/services/mediapackage.html#MediaPackage.Paginator.ListChannels.paginate)
+        [ListChannels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.7/reference/services/mediapackage.html#MediaPackage.Paginator.ListChannels.paginate)
         """
 
 
 class ListHarvestJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListHarvestJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.2/reference/services/mediapackage.html#MediaPackage.Paginator.ListHarvestJobs)
+    [Paginator.ListHarvestJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.7/reference/services/mediapackage.html#MediaPackage.Paginator.ListHarvestJobs)
     """
 
     def paginate(
@@ -53,20 +53,20 @@ class ListHarvestJobsPaginator(Boto3Paginator):
         IncludeChannelId: str = None,
         IncludeStatus: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListHarvestJobsResponseTypeDef, None, None]:
+    ) -> Iterator[ListHarvestJobsResponseTypeDef]:
         """
-        [ListHarvestJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.2/reference/services/mediapackage.html#MediaPackage.Paginator.ListHarvestJobs.paginate)
+        [ListHarvestJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.7/reference/services/mediapackage.html#MediaPackage.Paginator.ListHarvestJobs.paginate)
         """
 
 
 class ListOriginEndpointsPaginator(Boto3Paginator):
     """
-    [Paginator.ListOriginEndpoints documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.2/reference/services/mediapackage.html#MediaPackage.Paginator.ListOriginEndpoints)
+    [Paginator.ListOriginEndpoints documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.7/reference/services/mediapackage.html#MediaPackage.Paginator.ListOriginEndpoints)
     """
 
     def paginate(
         self, ChannelId: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListOriginEndpointsResponseTypeDef, None, None]:
+    ) -> Iterator[ListOriginEndpointsResponseTypeDef]:
         """
-        [ListOriginEndpoints.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.2/reference/services/mediapackage.html#MediaPackage.Paginator.ListOriginEndpoints.paginate)
+        [ListOriginEndpoints.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.7/reference/services/mediapackage.html#MediaPackage.Paginator.ListOriginEndpoints.paginate)
         """
